@@ -4,12 +4,12 @@ vtelem - Implements management of a synchronous task.
 
 # built-in
 import logging
-from typing import Callable, Any
+from typing import Any, Callable
 
 # internal
+from vtelem.classes import LOG_PERIOD
 from vtelem.daemon import DaemonBase, DaemonState
 from vtelem.enums.primitive import Primitive
-from vtelem.classes import LOG_PERIOD
 from vtelem.telemetry.environment import TelemetryEnvironment
 
 LOG = logging.getLogger(__name__)
