@@ -8,8 +8,7 @@ from typing import Dict
 
 # third-party
 from cerberus import Validator
-from datazen.code import ARBITER
-from datazen.load import load_dir
+from vcorelib.io import ARBITER
 
 SchemaMap = Dict[str, Validator]
 
@@ -25,8 +24,9 @@ def load_schema_dir(path: Path, **kwargs) -> SchemaMap:
     Load schemas from a directory, using file names (minus suffixes) as keys.
     """
 
-    assert path.is_dir()
-    data = load_dir(str(path), {}, are_templates=False)
+    data = ARBITER.decode_directory(
+        path, require_success=True, recurse=True
+    ).data
 
     schemas: SchemaMap = {}
     for key, value in data.items():
